@@ -54,4 +54,10 @@ class DescribeApplicationInstancesRequest(RoaRequest):
 		return self.get_query_params().get('CurrentPage')
 
 	def set_CurrentPage(self,CurrentPage):
-		self.add_query_param('CurrentPage',CurrentPage)
\ No newline at end of file
+		self.add_query_param('CurrentPage',CurrentPage)
+
+	def get_Reverse(self):
+		return self.get_query_params().get('Reverse')
+
+	def set_Reverse(self,Reverse):
+		self.add_query_param('Reverse',Reverse)
\ No newline at end of file
